==> com.liferay.headless.commerce.admin.account.impl-2.0.15-sources-commercial.jar: com/liferay/headless/commerce/admin/account/internal/jaxrs/exception/mapper/DuplicateCommerceAccountGroupCommerceAccountRelExceptionMapper.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.headless.commerce.admin.account.internal.jaxrs.exception.mapper;

import com.liferay.commerce.account.exception.DuplicateCommerceAccountGroupCommerceAccountRelException;
import com.liferay.headless.commerce.core.exception.mapper.BaseExceptionMapper;

import javax.ws.rs.core.Response;
import javax.ws.rs.ext.ExceptionMapper;
import javax.ws.rs.ext.Provider;

import org.osgi.service.component.annotations.Component;

/**
 * @author Andrea Sbarra
 */
@Component(
	property = {
		"osgi.jaxrs.application.select=(osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Account)",
		"osgi.jaxrs.extension=true",
		"osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Account.DuplicateCommerceAccountGroupCommerceAccountRelException.java"
	},
	service = ExceptionMapper.class
)
@Provider
public class DuplicateCommerceAccountGroupCommerceAccountRelExceptionMapper
	extends BaseExceptionMapper
		<DuplicateCommerceAccountGroupCommerceAccountRelException> {

	@Override
	public String getErrorDescription() {
		return "Duplicate account group - account relation";
	}

	@Override
	public Response.Status getStatus() {
		return Response.Status.CONFLICT;
	}

}

==> com.liferay.headless.commerce.admin.account.impl-2.0.43-sources-commercial.jar: com/liferay/headless/commerce/admin/account/internal/jaxrs/exception/mapper/DuplicateCommerceAccountGroupCommerceAccountRelExceptionMapper.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.headless.commerce.admin.account.internal.jaxrs.exception.mapper;

import com.liferay.commerce.account.exception.DuplicateCommerceAccountGroupCommerceAccountRelException;
import com.liferay.headless.commerce.core.exception.mapper.BaseExceptionMapper;

import javax.ws.rs.core.Response;
import javax.ws.rs.ext.ExceptionMapper;
import javax.ws.rs.ext.Provider;

import org.osgi.service.component.annotations.Component;

/**
 * @author Andrea Sbarra
 */
@Component(
	property = {
		"osgi.jaxrs.application.select=(osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Account)",
		"osgi.jaxrs.extension=true",
		"osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Account.DuplicateCommerceAccountGroupCommerceAccountRelExceptionMapper"
	},
	service = ExceptionMapper.class
)
@Provider
public class DuplicateCommerceAccountGroupCommerceAccountRelExceptionMapper
	extends BaseExceptionMapper
		<DuplicateCommerceAccountGroupCommerceAccountRelException> {

	@Override
	public String getErrorDescription() {
		return "Duplicate account group - account relation";
	}

	@Override
	public Response.Status getStatus() {
		return Response.Status.CONFLICT;
	}

}
